@@ -24,32 +24,35 @@
 #define CAPTIONDIALOG_H
 
 // Local includes
-#include "common.h"
+
 #include "ui_captiondialog.h"
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
-class SharedData;
+class SharedContainer;
 
 class CaptionDialog : public QWidget, Ui::CaptionDialog
 {
     Q_OBJECT
 
 public:
-    CaptionDialog(QWidget* parent, SharedData* sharedData);
+
+    CaptionDialog(QWidget* parent, SharedContainer* sharedData);
     ~CaptionDialog();
 
     void readSettings();
     void saveSettings();
 
 private Q_SLOTS:
-    void slotCommentsFontColorChanged( void );
-    void slotCommentsBgColorChanged( void );
-    void slotTransparentBgToggled( void );
+
+    void slotCommentsFontColorChanged();
+    void slotCommentsBgColorChanged();
+    void slotTransparentBgToggled();
 
 private:
-    SharedData*       m_sharedData;
+
+    SharedContainer* m_sharedData;
 };
 
 } // namespace KIPIAdvancedSlideshowPlugin
