@@ -43,21 +43,24 @@ namespace KIPIBatchProcessImagesPlugin
 {
 
 ConvertOptionsDialog::ConvertOptionsDialog(QWidget *parent, int ImageFormatType)
-        : KDialog(parent)
+                    : KDialog(parent)
 {
     setCaption(i18n("Image File Format Options"));
     setModal(true);
     setButtons(Ok | Cancel);
     setDefaultButton(Ok);
-    QWidget* box = new QWidget(this);
+    QWidget* box       = new QWidget(this);
+    QVBoxLayout *dvlay = new QVBoxLayout(box);
+    dvlay->setSpacing(spacingHint());
+    dvlay->setMargin(spacingHint());
     setMainWidget(box);
-    QVBoxLayout *dvlay = new QVBoxLayout(box, 10, spacingHint());
     QString whatsThis;
 
-    if (ImageFormatType == 0 || ImageFormatType == 1) { // JPEG || PNG
+    if (ImageFormatType == 0 || ImageFormatType == 1)
+    { // JPEG || PNG
         m_label_imageCompression = new QLabel(i18n("Image compression level:"), box);
         dvlay->addWidget(m_label_imageCompression);
-        m_JPEGPNGCompression = new KIntNumInput(75, box);
+        m_JPEGPNGCompression     = new KIntNumInput(75, box);
         m_JPEGPNGCompression->setRange(1, 100);
         m_JPEGPNGCompression->setSliderEnabled(true);
         whatsThis = i18n("<p>The compression value for the target images:</p>");
@@ -73,34 +76,38 @@ ConvertOptionsDialog::ConvertOptionsDialog(QWidget *parent, int ImageFormatType)
         m_label_imageCompression->setBuddy(m_JPEGPNGCompression);
         dvlay->addWidget(m_JPEGPNGCompression);
 
-        if (ImageFormatType == 0) { // JPEG
+        if (ImageFormatType == 0)
+        { // JPEG
             m_compressLossLess = new QCheckBox(i18n("Use lossless compression"), box);
             m_compressLossLess->setWhatsThis(i18n("If this option is enabled, "
                                                   "all JPEG operations will use lossless compression."));
             dvlay->addWidget(m_compressLossLess);
 
-            connect(m_compressLossLess, SIGNAL(toggled(bool)), this, SLOT(slotCompressLossLessEnabled(bool)));
+            connect(m_compressLossLess, SIGNAL(toggled(bool)),
+                    this, SLOT(slotCompressLossLessEnabled(bool)));
         }
     }
 
-    if (ImageFormatType == 2) { // TIFF
+    if (ImageFormatType == 2)
+    { // TIFF
         QLabel *m_label_imageCompression = new QLabel(i18n("Image compression algorithm:"), box);
         dvlay->addWidget(m_label_imageCompression);
         m_TIFFCompressionAlgo = new KComboBox(box);
-        m_TIFFCompressionAlgo->insertItem("LZW");
-        m_TIFFCompressionAlgo->insertItem("JPEG");
-        m_TIFFCompressionAlgo->insertItem(i18nc("No TIFF compression", "None"));
+        m_TIFFCompressionAlgo->addItem("LZW");
+        m_TIFFCompressionAlgo->addItem("JPEG");
+        m_TIFFCompressionAlgo->addItem(i18nc("No TIFF compression", "None"));
         m_TIFFCompressionAlgo->setWhatsThis(i18n("Select here the compression algorithm."));
         m_label_imageCompression->setBuddy(m_TIFFCompressionAlgo);
         dvlay->addWidget(m_TIFFCompressionAlgo);
     }
 
-    if (ImageFormatType == 5) { // TGA
+    if (ImageFormatType == 5)
+      { // TGA
         QLabel *m_label_imageCompression = new QLabel(i18n("Image compression algorithm:"), box);
         dvlay->addWidget(m_label_imageCompression);
         m_TGACompressionAlgo = new KComboBox(box);
-        m_TGACompressionAlgo->insertItem("RLE");
-        m_TGACompressionAlgo->insertItem(i18nc("No TGA compression", "None"));
+        m_TGACompressionAlgo->addItem("RLE");
+        m_TGACompressionAlgo->addItem(i18nc("No TGA compression", "None"));
         m_TGACompressionAlgo->setWhatsThis(i18n("Select here the compression algorithm."));
         m_label_imageCompression->setBuddy(m_TGACompressionAlgo);
         dvlay->addWidget(m_TGACompressionAlgo);
