@@ -35,7 +35,7 @@
 
 #include "kpaboutdata.h"
 
-class QTextBrowser;
+class KTextBrowser;
 
 namespace KIPIBatchProcessImagesPlugin
 {
@@ -46,8 +46,8 @@ class OutputDialog : public KDialog
 
 public:
 
-    OutputDialog(QWidget* parent = 0, const QString& caption = QString(),
-                 const QString& Messages = QString(), const QString& Header = QString());
+    explicit OutputDialog(QWidget* parent = 0, const QString& caption = QString(),
+                          const QString& Messages = QString(), const QString& Header = QString());
     ~OutputDialog();
 
 private Q_SLOTS:
@@ -57,7 +57,7 @@ private Q_SLOTS:
 
 private:
 
-    QTextBrowser*             m_debugView;
+    KTextBrowser*             m_debugView;
 
     KIPIPlugins::KPAboutData* m_about;
 };
