@@ -6,7 +6,7 @@
  * Date        : 2003-11-03
  * Description : month image selection widget.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006 by Tom Albers <tomalbers@kde.nl>
  * Copyright (C) 2007-2008 by Orgad Shaneh <orgads at gmail dot com>
  *
@@ -147,8 +147,7 @@ void MonthWidget::setImage( const KUrl &url )
         // Check if image can be loaded by native Qt loader.
         if ( QImageReader::imageFormat( url.path() ).isEmpty() )
         {
-            kWarning( 51001 ) << "Unknown image format for: "
-                              << url.prettyUrl() << endl;
+            kWarning( AREA_CODE_LOADING ) << "Unknown image format for: " << url.prettyUrl();
             return;
         }
     }
