@@ -8,6 +8,7 @@
  *
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -62,7 +63,7 @@ class KIPIPLUGINS_EXPORT ImagesListViewItem : public QTreeWidgetItem
 
 public:
 
-    ImagesListViewItem(ImagesListView* view, const KUrl& url);
+    explicit ImagesListViewItem(ImagesListView* view, const KUrl& url);
     ~ImagesListViewItem();
 
     void setUrl(const KUrl& url);
@@ -78,6 +79,9 @@ public:
     int rating();
 
     void setThumb(const QPixmap& pix);
+    void setProgressAnimation(const QPixmap& pix);
+
+    void setProcessedIcon(const QIcon& icon);
 
     void updateInformation();
 
@@ -87,6 +91,7 @@ private:
     QString         m_comments;       // Image comments from Kipi host.
     QStringList     m_tags;           // List of keywords from Kipi host.
     KUrl            m_url;            // Image url provided by Kipi host.
+    QPixmap         m_thumb;          // Image thumbnail
     ImagesListView* m_view;
 };
 
@@ -110,14 +115,16 @@ public:
         User6
     };
 
-    ImagesListView(ImagesList *parent = 0);
-    ImagesListView(int iconSize, ImagesList *parent = 0);
+    explicit ImagesListView(ImagesList *parent = 0);
+    explicit ImagesListView(int iconSize, ImagesList *parent = 0);
     ~ImagesListView();
 
     void setColumnLabel(ColumnType column, const QString& label);
     void setColumnEnabled(ColumnType column, bool enable);
     void setColumn(ColumnType column, const QString& label, bool enable);
 
+    ImagesListViewItem* findItem(const KUrl& url);
+
     KIPI::Interface* iface() const;
 
 Q_SIGNALS:
@@ -186,7 +193,7 @@ public:
     };
     Q_DECLARE_FLAGS(ControlButtons, ControlButton)
 
-    ImagesList(KIPI::Interface* iface, QWidget* parent = 0, int iconSize = -1);
+    explicit ImagesList(KIPI::Interface* iface, QWidget* parent = 0, int iconSize = -1);
     virtual ~ImagesList();
 
     void               setAllowRAW(bool allow);
@@ -200,6 +207,10 @@ public:
     virtual KUrl::List imageUrls() const;
     virtual void       removeItemByUrl(const KUrl& url);
 
+    void               processing(const KUrl& url);
+    void               processed(bool success);
+    void               clearProcessedStatus();
+
     void               setControlButtons(ControlButtons buttonMask);
     void               setControlButtonsPlacement(ControlButtonPlacement placement);
     void               enableControlButtons(bool enable = true);
@@ -226,6 +237,7 @@ protected Q_SLOTS:
     virtual void slotLoadItems() {};
     virtual void slotSaveItems() {};
 
+    void slotProgressTimerDone();
     virtual void slotThumbnail(const KUrl& url, const QPixmap& pix);
     virtual void slotImageListChanged();
 
