@@ -23,12 +23,15 @@
 
 //#define ENABLE_DEBUG_MESSAGES 1
 
+#include "kpwriteimage.h"
+#include "kpwritehelp.h"
+
 // C ANSI includes
 
 extern "C"
 {
-#include <unistd.h>
 #ifndef _WIN32
+#include <unistd.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #endif
@@ -48,8 +51,12 @@ extern "C"
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
+// LibKExiv2 includes
+
+#include <libkexiv2/version.h>
+
 // Local includes
-#include "kpwriteimage.h"
+
 #include "pluginsversion.h"
 
 namespace KIPIPlugins
@@ -141,8 +148,8 @@ void KPWriteImage::setImageData(const QByteArray& data, uint width, uint height,
 
 bool KPWriteImage::write2JPEG(const QString& destPath)
 {
-    FILE* file = fopen(QFile::encodeName(destPath), "wb");
-    if (!file)
+    QFile file(destPath);
+    if (!file.open(QIODevice::ReadWrite))
     {
         kDebug() << "Failed to open JPEG file for writing" ;
         return false;
@@ -152,9 +159,9 @@ bool KPWriteImage::write2JPEG(const QString& destPath)
     struct jpeg_error_mgr       jerr;
 
     // Init JPEG compressor.
-    cinfo.err = jpeg_std_error(&jerr);
+    cinfo.err              = jpeg_std_error(&jerr);
     jpeg_create_compress(&cinfo);
-    jpeg_stdio_dest(&cinfo, file);
+    kp_jpeg_qiodevice_dest(&cinfo, &file);
     cinfo.image_width      = d->width;
     cinfo.image_height     = d->height;
     cinfo.input_components = 3;
@@ -193,7 +200,7 @@ bool KPWriteImage::write2JPEG(const QString& destPath)
             {
                 delete [] line;
                 jpeg_destroy_compress(&cinfo);
-                fclose(file);
+                file.close();
                 return false;
             }
 
@@ -222,7 +229,7 @@ bool KPWriteImage::write2JPEG(const QString& destPath)
             {
                 delete [] line;
                 jpeg_destroy_compress(&cinfo);
-                fclose(file);
+                file.close();
                 return false;
             }
 
@@ -246,7 +253,7 @@ bool KPWriteImage::write2JPEG(const QString& destPath)
 
     jpeg_finish_compress(&cinfo);
     jpeg_destroy_compress(&cinfo);
-    fclose(file);
+    file.close();
 
     d->metadata.save(destPath);
 
@@ -333,8 +340,12 @@ bool KPWriteImage::write2PPM(const QString& destPath)
 
 bool KPWriteImage::write2PNG(const QString& destPath)
 {
-    FILE* file = fopen(QFile::encodeName(destPath), "wb");
-    if (!file)
+    /*
+    check this out for b/w support:
+    http://lxr.kde.org/source/playground/graphics/krita-exp/kis_png_converter.cpp#607
+    */
+    QFile file(destPath);
+    if (!file.open(QIODevice::ReadWrite))
     {
         kDebug() << "Failed to open PNG file for writing" ;
         return false;
@@ -346,7 +357,8 @@ bool KPWriteImage::write2PNG(const QString& destPath)
     png_bytep    row_ptr;
     png_structp  png_ptr    = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
     png_infop    info_ptr   = png_create_info_struct(png_ptr);
-    png_init_io(png_ptr, file);
+
+    png_set_write_fn(png_ptr, (void*)&file, kp_png_write_fn, kp_png_flush_fn);
 
     if (QSysInfo::ByteOrder == QSysInfo::LittleEndian)      // Intel
         png_set_bgr(png_ptr);
@@ -393,16 +405,22 @@ bool KPWriteImage::write2PNG(const QString& destPath)
     // Write Software info.
     QString libpngver(PNG_HEADER_VERSION_STRING);
     libpngver.replace('\n', ' ');
-    QString soft = d->kipipluginsVer;
+    QString soft     = d->kipipluginsVer;
     soft.append(QString(" (%1)").arg(libpngver));
     png_text text;
-    text.key  = (png_charp)"Software";
-    text.text = soft.toAscii().data();
+    text.key         = (png_charp)"Software";
+    text.text        = soft.toAscii().data();
     text.compression = PNG_TEXT_COMPRESSION_zTXt;
     png_set_text(png_ptr, info_ptr, &(text), 1);
 
     // Store Exif data.
+
+#if KEXIV2_VERSION >= 0x010000
+    QByteArray ba = d->metadata.getExifEncoded(true);
+#else
     QByteArray ba = d->metadata.getExif(true);
+#endif
+
     writeRawProfile(png_ptr, info_ptr, (png_charp)"exif", ba.data(), (png_uint_32) ba.size());
 
     // Store Iptc data.
@@ -420,12 +438,12 @@ bool KPWriteImage::write2PNG(const QString& destPath)
     uchar* ptr = (uchar*)d->data.data();
     uint   x, y, j;
 
-    for (y = 0; y < d->height; y++)
+    for (y = 0; y < d->height; ++y)
     {
         if (cancel())
         {
             delete [] data;
-            fclose(file);
+            file.close();
             png_destroy_write_struct(&png_ptr, (png_infopp) & info_ptr);
             png_destroy_info_struct(png_ptr, (png_infopp) & info_ptr);
             return false;
@@ -487,8 +505,7 @@ bool KPWriteImage::write2PNG(const QString& destPath)
     png_write_end(png_ptr, info_ptr);
     png_destroy_write_struct(&png_ptr, (png_infopp) & info_ptr);
     png_destroy_info_struct(png_ptr, (png_infopp) & info_ptr);
-    fclose(file);
-
+    file.close();
     return true;
 }
 
@@ -600,7 +617,7 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
         return false;
     }
 
-    for (y = 0; y < h; y++)
+    for (y = 0; y < h; ++y)
     {
         if (cancel())
         {
@@ -611,7 +628,7 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
 
         i = 0;
 
-        for (x = 0; x < w; x++)
+        for (x = 0; x < w; ++x)
         {
             pixel = &data[((y * w) + x) * bytesDepth()];
 
@@ -714,11 +731,11 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
             return false;
         }
 
-        for (y = 0 ; y < uint32(thumb.height()) ; y++)
+        for (y = 0 ; y < uint32(thumb.height()) ; ++y)
         {
             i = 0;
 
-            for (x = 0 ; x < uint32(thumb.width()) ; x++)
+            for (x = 0 ; x < uint32(thumb.width()) ; ++x)
             {
                 pixelThumb = &dataThumb[((y * thumb.width()) + x) * 4];
 
@@ -835,7 +852,7 @@ void KPWriteImage::writeRawProfile(png_struct *ping, png_info *ping_info, char *
 
     dp += 8;
 
-    for (i=0; i < (long) length; i++)
+    for (i=0; i < (long) length; ++i)
     {
         if (i%36 == 0)
             *dp++='\n';
