@@ -61,6 +61,7 @@ public:
     {
         backupOriginalRawFile = false;
         compressLossLess      = true;
+        updateFileDate        = false;
         running               = false;
         previewMode           = DNGWriter::MEDIUM;
     }
@@ -75,6 +76,7 @@ public:
 
     bool           backupOriginalRawFile;
     bool           compressLossLess;
+    bool           updateFileDate;
     bool           running;
 
     int            previewMode;
@@ -91,7 +93,7 @@ public:
 ActionThread::ActionThread(QObject *parent)
             : QThread(parent), d(new ActionThreadPriv)
 {
-    qRegisterMetaType<ActionData>("ActionData");
+    qRegisterMetaType<ActionData>();
 }
 
 ActionThread::~ActionThread()
@@ -114,6 +116,11 @@ void ActionThread::setCompressLossLess(bool b)
     d->compressLossLess = b;
 }
 
+void ActionThread::setUpdateFileDate(bool b)
+{
+    d->updateFileDate = b;
+}
+
 void ActionThread::setPreviewMode(int mode)
 {
     d->previewMode = mode;
@@ -299,6 +306,7 @@ void ActionThread::run()
                     d->dngProcessor.setOutputFile(destPath);
                     d->dngProcessor.setBackupOriginalRawFile(d->backupOriginalRawFile);
                     d->dngProcessor.setCompressLossLess(d->compressLossLess);
+                    d->dngProcessor.setUpdateFileDate(d->updateFileDate);
                     d->dngProcessor.setPreviewMode(d->previewMode);
                     int ret = d->dngProcessor.convert();
 
@@ -313,11 +321,10 @@ void ActionThread::run()
 
                 default:
                 {
-                    kError(51000) << "KIPIDNGConverterPlugin:ActionThread: "
+                    kError() << "KIPIDNGConverterPlugin:ActionThread: "
                                   << "Unknown action specified";
                 }
             }
-
         }
 
         delete t;
