@@ -38,7 +38,6 @@
 // Local includes
 
 #include "aboutdata.h"
-#include "plugin_dngconverter.h"
 #include "pluginsversion.h"
 #include "batchdialog.h"
 
@@ -47,9 +46,9 @@ using namespace KExiv2Iface;
 
 int main(int argc, char *argv[])
 {
-    DNGConverterAboutData aboutData;
+    DNGConverterAboutData* aboutData = new DNGConverterAboutData;
 
-    KCmdLineArgs::init(argc, argv, &aboutData);
+    KCmdLineArgs::init(argc, argv, aboutData);
 
     KCmdLineOptions options;
     options.add("+[file(s)]", ki18n("File(s) to convert"));
@@ -61,8 +60,8 @@ int main(int argc, char *argv[])
 
     KApplication app;
 
-    aboutData.setProgramLogo(KIcon("dngconverter"));
-    BatchDialog *converter = new BatchDialog(0, &aboutData);
+    aboutData->setProgramLogo(KIcon("dngconverter"));
+    BatchDialog *converter = new BatchDialog(0, aboutData);
     app.setTopWidget(converter);
 
     KUrl::List urls;
@@ -70,7 +69,7 @@ int main(int argc, char *argv[])
     for(int i = 0; i < args->count(); i++)
     {
         KUrl url = args->url(i);
-        if (Plugin_DNGConverter::isRAWFile(url.path()))
+        if (DNGConverterAboutData::isRAWFile(url.path()))
             urls.append(url);
     }
     args->clear();
