@@ -31,6 +31,7 @@
 #include <QGroupBox>
 #include <QRadioButton>
 #include <QButtonGroup>
+#include <QProgressBar>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
@@ -86,7 +87,7 @@ FbWidget::FbWidget(QWidget* parent, KIPI::Interface *iface, bool import)
         i18n("This is the Facebook account that is currently logged in."));
     QGridLayout* accountBoxLayout = new QGridLayout(accountBox);
 
-    QLabel *userNameLbl     = new QLabel(i18n("Name:"), accountBox);
+    QLabel *userNameLbl     = new QLabel(i18nc("facebook account settings", "Name:"), accountBox);
     m_userNameDisplayLbl    = new QLabel(accountBox);
     QLabel *permissionLbl   = new QLabel(i18n("Permission:"), accountBox);
     permissionLbl->setWhatsThis(
@@ -158,7 +159,7 @@ FbWidget::FbWidget(QWidget* parent, KIPI::Interface *iface, bool import)
             KGuiItem(i18n("New Album"), "list-add",
                      i18n("Create new Facebook album")), accountBox);
     m_reloadAlbumsBtn   = new KPushButton(
-            KGuiItem(i18n("Reload"), "view-refresh",
+            KGuiItem(i18nc("facebook album list", "Reload"), "view-refresh",
                      i18n("Reload album list")), accountBox);
 
     albumsBoxLayout->addWidget(albMeRBtn,           0, 0, 1, 2);
@@ -218,6 +219,10 @@ FbWidget::FbWidget(QWidget* parent, KIPI::Interface *iface, bool import)
     optionsBoxLayout->setSpacing(KDialog::spacingHint());
     optionsBoxLayout->setMargin(KDialog::spacingHint());
 
+    m_progressBar = new QProgressBar(settingsBox);
+    m_progressBar->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
+    m_progressBar->hide();
+
     // ------------------------------------------------------------------------
 
     settingsBoxLayout->addWidget(m_headerLbl);
@@ -225,6 +230,7 @@ FbWidget::FbWidget(QWidget* parent, KIPI::Interface *iface, bool import)
     settingsBoxLayout->addWidget(albBox);
     settingsBoxLayout->addWidget(uploadBox);
     settingsBoxLayout->addWidget(optionsBox);
+    settingsBoxLayout->addWidget(m_progressBar);
     settingsBoxLayout->setSpacing(KDialog::spacingHint());
     settingsBoxLayout->setMargin(KDialog::spacingHint());
 
@@ -289,9 +295,14 @@ KIPIPlugins::ImagesList* FbWidget::imagesList() const
     return m_imgList;
 }
 
+QProgressBar* FbWidget::progressBar() const
+{
+    return m_progressBar;
+}
+
 QString FbWidget::getDestinationPath()
 {
-    return m_uploadWidget->selectedImageCollection().uploadPath().path();
+    return m_uploadWidget->selectedImageCollection().uploadPath().toLocalFile();
 }
 
 void FbWidget::updateLabels(const QString& name, const QString& url, bool uplPerm)
