@@ -30,6 +30,7 @@
 #include <QFileInfo>
 #include <QSpinBox>
 #include <QCheckBox>
+#include <QProgressBar>
 #include <QCloseEvent>
 
 // KDE includes
@@ -43,7 +44,6 @@
 #include <KComboBox>
 #include <KPushButton>
 #include <KMessageBox>
-#include <KProgressDialog>
 #include <KToolInvocation>
 
 // LibKExiv2 includes
@@ -90,8 +90,8 @@ FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
 
     setMainWidget(m_widget);
     setWindowIcon(KIcon("facebook"));
-    setButtons(Help|User1|Close);
-    setDefaultButton(Close);
+    setButtons(Help|User1|Cancel);
+    setDefaultButton(Cancel);
     setModal(false);
 
     if (import)
@@ -128,9 +128,6 @@ FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
     connect(m_widget, SIGNAL( reloadAlbums(long long) ),
             this, SLOT( slotReloadAlbumsRequest(long long)) );
 
-    connect(this, SIGNAL( closeClicked() ),
-            this, SLOT( slotClose()) );
-
     connect(this, SIGNAL( user1Clicked() ),
             this, SLOT( slotStartTransfer()) );
 
@@ -216,11 +213,32 @@ void FbWindow::slotHelp()
     KToolInvocation::invokeHelp("facebook", "kipi-plugins");
 }
 
-void FbWindow::slotClose()
+void FbWindow::slotButtonClicked(int button)
 {
-    writeSettings();
-    m_widget->imagesList()->listView()->clear();
-    done(Close);
+    kDebug() << "TODO: FbWindow::slotButtonClicked";
+    switch (button)
+    {
+        case Cancel:
+            if (m_widget->progressBar()->isHidden())
+            {
+                writeSettings();
+                m_widget->imagesList()->listView()->clear();
+                done(Close);
+            }
+            else // cancel login/transfer
+            {
+                m_talker->cancel();
+                m_transferQueue.clear();
+                m_widget->m_imgList->processed(false);
+                m_widget->progressBar()->hide();
+            }
+            break;
+        case User1:
+            slotStartTransfer();
+            break;
+        default:
+             KDialog::slotButtonClicked(button);
+    }
 }
 
 void FbWindow::reactivate()
@@ -300,14 +318,8 @@ void FbWindow::writeSettings()
 
 void FbWindow::authenticate()
 {
-    m_authProgressDlg = new KProgressDialog(this, i18n("Authentication"));
-    m_authProgressDlg->setMinimumDuration(0);
-    m_authProgressDlg->setModal(true);
-    m_authProgressDlg->setAutoReset(true);
-    m_authProgressDlg->setAutoClose(true);
-
-    connect(m_authProgressDlg, SIGNAL( cancelClicked() ),
-            this, SLOT( slotLoginCancel() ));
+    m_widget->progressBar()->show();
+    m_widget->progressBar()->setFormat("");
 
     kDebug() << "Calling Login method";
     m_talker->authenticate(m_sessionKey, m_sessionSecret, m_sessionExpires);
@@ -315,21 +327,20 @@ void FbWindow::authenticate()
 
 void FbWindow::slotLoginProgress(int step, int maxStep, const QString& label)
 {
-    if (!m_authProgressDlg)
-        return;
+    QProgressBar* progressBar = m_widget->progressBar();
 
     if (!label.isEmpty())
-        m_authProgressDlg->setLabelText(label);
+        progressBar->setFormat(label);
 
     if (maxStep > 0)
-        m_authProgressDlg->progressBar()->setMaximum(maxStep);
+        progressBar->setMaximum(maxStep);
 
-    m_authProgressDlg->progressBar()->setValue(step);
+    progressBar->setValue(step);
 }
 
 void FbWindow::slotLoginDone(int errCode, const QString& errMsg)
 {
-    m_authProgressDlg->hide();
+    m_widget->progressBar()->hide();
 
     buttonStateChange(m_talker->loggedIn());
     FbUser user = m_talker->getUser();
@@ -337,7 +348,7 @@ void FbWindow::slotLoginDone(int errCode, const QString& errMsg)
     m_widget->updateLabels(user.name, user.profileURL, user.uploadPerm);
     m_widget->m_albumsCoB->clear();
     if (!m_import)
-        m_widget->m_albumsCoB->addItem(i18n("<auto create>"), 0);
+        m_widget->m_albumsCoB->addItem(i18n("&lt;auto create&gt;"), 0);
 
     m_sessionKey     = m_talker->getSessionKey();
     m_sessionSecret  = m_talker->getSessionSecret();
@@ -373,9 +384,9 @@ void FbWindow::slotListAlbumsDone(int errCode, const QString& errMsg, const QLis
 {
 
     QString albumDebug = "";
-    foreach(FbAlbum album, albumsList)
+    foreach(const FbAlbum &album, albumsList)
     {
-        albumDebug.append(QString::number(album.id) + ": " + album.title + "\n");
+        albumDebug.append(QString::number(album.id) + ": " + album.title + '\n');
     }
     kDebug() << "Received albums (errCode = " << errCode << ", errMsg = "
                   << errMsg << "): " << albumDebug;
@@ -396,7 +407,7 @@ void FbWindow::slotListAlbumsDone(int errCode, const QString& errMsg, const QLis
     }
     else
     {
-        m_widget->m_albumsCoB->addItem(i18n("<auto create>"), 0);
+        m_widget->m_albumsCoB->addItem(i18n("&lt;auto create&gt;"), 0);
     }
 
     for (int i = 0; i < albumsList.size(); ++i)
@@ -446,15 +457,8 @@ void FbWindow::slotListPhotosDone(int errCode, const QString& errMsg, const QLis
     m_imagesTotal = m_transferQueue.count();
     m_imagesCount = 0;
 
-    m_progressDlg = new KProgressDialog(this, i18n("Transfer Progress"));
-    m_progressDlg->setMinimumDuration(0);
-    m_progressDlg->setModal(true);
-    m_progressDlg->setAutoReset(true);
-    m_progressDlg->setAutoClose(true);
-    m_progressDlg->progressBar()->setFormat(i18n("%v / %m"));
-
-    connect(m_progressDlg, SIGNAL( cancelClicked() ),
-            this, SLOT( slotTransferCancel() ));
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(0);
 
     // start download with first photo in queue
     downloadNextPhoto();
@@ -555,22 +559,22 @@ void FbWindow::slotNewAlbumRequest()
     }
 }
 
-void FbWindow::slotLoginCancel()
-{
-    m_talker->cancel();
-    m_authProgressDlg->hide();
-}
-
 void FbWindow::slotStartTransfer()
 {
     kDebug() << "slotStartTransfer invoked";
 
     if (m_import)
     {
+        m_widget->progressBar()->setFormat(i18n("%v / %m"));
+        m_widget->progressBar()->setMaximum(0);
+        m_widget->progressBar()->setValue(0);
+        m_widget->progressBar()->show();
+
         m_talker->listPhotos(m_widget->getFriendID(), m_widget->getAlbumID());
     }
     else
     {
+        m_widget->m_imgList->clearProcessedStatus();
         m_transferQueue = m_widget->m_imgList->imageUrls();
 
         if (m_transferQueue.isEmpty())
@@ -582,15 +586,10 @@ void FbWindow::slotStartTransfer()
         m_imagesTotal = m_transferQueue.count();
         m_imagesCount = 0;
 
-        m_progressDlg = new KProgressDialog(this, i18n("Transfer Progress"));
-        m_progressDlg->setMinimumDuration(0);
-        m_progressDlg->setModal(true);
-        m_progressDlg->setAutoReset(true);
-        m_progressDlg->setAutoClose(true);
-        m_progressDlg->progressBar()->setFormat(i18n("%v / %m"));
-
-        connect(m_progressDlg, SIGNAL( cancelClicked() ),
-                this, SLOT( slotTransferCancel() ));
+        m_widget->progressBar()->setFormat(i18n("%v / %m"));
+        m_widget->progressBar()->setMaximum(m_imagesTotal);
+        m_widget->progressBar()->setValue(0);
+        m_widget->progressBar()->show();
 
         uploadNextPhoto();
     }
@@ -694,14 +693,15 @@ void FbWindow::uploadNextPhoto()
 {
     if (m_transferQueue.isEmpty())
     {
-        m_progressDlg->hide();
+        m_widget->progressBar()->hide();
         return;
     }
 
-    m_progressDlg->progressBar()->setMaximum(m_imagesTotal);
-    m_progressDlg->progressBar()->setValue(m_imagesCount);
+    m_widget->m_imgList->processing(m_transferQueue.first());
+    QString imgPath = m_transferQueue.first().toLocalFile();
 
-    QString imgPath = m_transferQueue.first().path();
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(m_imagesCount);
 
     // check if we have to RAW file -> use preview image then
 #if KDCRAW_VERSION < 0x000400
@@ -739,9 +739,6 @@ void FbWindow::uploadNextPhoto()
         slotAddPhotoDone(666, i18n("Cannot open file"));
         return;
     }
-
-    m_progressDlg->setLabelText(i18n("Uploading file %1",
-                                     m_transferQueue.first().path()));
 }
 
 void FbWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
@@ -753,8 +750,7 @@ void FbWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
         m_tmpPath.clear();
     }
 
-    // Remove photo uploaded from the list
-    m_widget->m_imgList->removeItemByUrl(m_transferQueue.first());
+    m_widget->m_imgList->processed(errCode == 0);
     m_transferQueue.pop_front();
 
     if (errCode == 0)
@@ -769,8 +765,8 @@ void FbWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
                               "Do you want to continue?", errMsg))
                          != KMessageBox::Continue)
         {
+            m_widget->progressBar()->hide();
             m_transferQueue.clear();
-            m_progressDlg->hide();
             return;
         }
     }
@@ -782,18 +778,16 @@ void FbWindow::downloadNextPhoto()
 {
     if (m_transferQueue.isEmpty())
     {
-        m_progressDlg->hide();
+        m_widget->progressBar()->hide();
         return;
     }
 
-    m_progressDlg->progressBar()->setMaximum(m_imagesTotal);
-    m_progressDlg->progressBar()->setValue(m_imagesCount);
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(m_imagesCount);
 
     QString imgPath = m_transferQueue.first().url();
 
     m_talker->getPhoto(imgPath);
-
-    m_progressDlg->setLabelText(i18n("Downloading file %1", imgPath));
 }
 
 void FbWindow::slotGetPhotoDone(int errCode, const QString& errMsg, const QByteArray& photoData)
@@ -831,8 +825,8 @@ void FbWindow::slotGetPhotoDone(int errCode, const QString& errMsg, const QByteA
                                   "Do you want to continue?", errText))
                              != KMessageBox::Continue)
             {
+                m_widget->progressBar()->hide();
                 m_transferQueue.clear();
-                m_progressDlg->hide();
                 return;
             }
         }
@@ -845,8 +839,8 @@ void FbWindow::slotGetPhotoDone(int errCode, const QString& errMsg, const QByteA
                               "Do you want to continue?", errMsg))
                          != KMessageBox::Continue)
         {
+            m_widget->progressBar()->hide();
             m_transferQueue.clear();
-            m_progressDlg->hide();
             return;
         }
     }
@@ -854,14 +848,6 @@ void FbWindow::slotGetPhotoDone(int errCode, const QString& errMsg, const QByteA
     downloadNextPhoto();
 }
 
-void FbWindow::slotTransferCancel()
-{
-    m_transferQueue.clear();
-    m_progressDlg->hide();
-
-    m_talker->cancel();
-}
-
 void FbWindow::slotCreateAlbumDone(int errCode, const QString& errMsg, long long newAlbumID)
 {
     if (errCode != 0)
