@@ -6,7 +6,7 @@
 * Date        : 2003-10-01
 * Description : a plugin to export to a remote Gallery server.
 *
-* Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+* Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
 * Copyright (C) 2006 by Colin Guthrie <kde@colin.guthr.ie>
 * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
 * Copyright (C) 2008 by Andrea Diamantini <adjam7 at gmail dot com>
@@ -65,6 +65,8 @@ public:
         GE_ADDPHOTO
     };
 
+public:
+
     GalleryTalker(QWidget* parent);
     ~GalleryTalker();
 
@@ -85,14 +87,15 @@ public:
 
     bool loggedIn() const;
 
-    void login(const KUrl& url, const QString& name,
-               const QString& passwd);
+    void login(const KUrl& url, const QString& name, const QString& passwd);
     void listAlbums();
     void listPhotos(const QString& albumName);
+
     void createAlbum(const QString& parentAlbumName,
                      const QString& albumName,
                      const QString& albumTitle,
                      const QString& albumCaption);
+
     bool addPhoto(const QString& albumName,
                   const QString& photoPath,
                   const QString& caption = QString(),
@@ -101,7 +104,6 @@ public:
 
     void cancel();
 
-
 Q_SIGNALS:
 
     void signalError(const QString& msg);
