@@ -42,8 +42,6 @@ public:
     {
     }
 
-    QDateTime        dateTime;
-
     GPSTrackListItem data;
 };
 
@@ -63,16 +61,15 @@ bool GPSTrackListViewItem::isDirty() const
     return d->data.isDirty();
 }
 
-void GPSTrackListViewItem::setGPSInfo(const QDateTime& dt, const GPSTrackListItem& data)
+void GPSTrackListViewItem::setGPSInfo(const GPSTrackListItem& data)
 {
-    d->dateTime = dt;
-    d->data     = data;
+    d->data = data;
     setText(KIPIPlugins::ImagesListView::User1, QString::number(d->data.id()));
     setText(KIPIPlugins::ImagesListView::Filename, d->data.fileName());
-    setText(KIPIPlugins::ImagesListView::User2, d->dateTime.toString(Qt::LocalDate));
-    setText(KIPIPlugins::ImagesListView::User3, QString::number(d->data.gpsData().latitude(),  'g', 12));
-    setText(KIPIPlugins::ImagesListView::User4, QString::number(d->data.gpsData().longitude(), 'g', 12));
-    setText(KIPIPlugins::ImagesListView::User5, QString::number(d->data.gpsData().altitude(),  'g', 12));
+    setText(KIPIPlugins::ImagesListView::User2, d->data.dateTime().toString(Qt::LocalDate));
+    setText(KIPIPlugins::ImagesListView::User3, d->data.gpsData().latitudeString());
+    setText(KIPIPlugins::ImagesListView::User4, d->data.gpsData().longitudeString());
+    setText(KIPIPlugins::ImagesListView::User5, d->data.gpsData().altitudeString());
     setText(KIPIPlugins::ImagesListView::User6, isDirty() ? i18n("Yes") : i18n("No"));
 }
 
@@ -81,24 +78,4 @@ GPSTrackListItem GPSTrackListViewItem::gpsInfo() const
     return d->data;
 }
 
-QDateTime GPSTrackListViewItem::dateTime() const
-{
-    return d->dateTime;
-}
-
-KUrl GPSTrackListViewItem::url() const
-{
-    return d->data.url();
-}
-
-QString GPSTrackListViewItem::fileName() const
-{
-    return d->data.fileName();
-}
-
-int GPSTrackListViewItem::id() const
-{
-    return d->data.id();
-}
-
 } // namespace KIPIGPSSyncPlugin
