@@ -23,6 +23,9 @@
 
 #define XMD_H
 
+#include "convert2grayscale.h"
+#include "convert2grayscale.moc"
+
 // C++ includes
 
 #include <cstdio>
@@ -58,8 +61,6 @@ extern "C"
 #include "utils.h"
 #include "pluginsversion.h"
 #include "transupp.h"
-#include "convert2grayscale.h"
-#include "convert2grayscale.moc"
 
 namespace KIPIJPEGLossLessPlugin
 {
@@ -117,7 +118,7 @@ bool ImageGrayScale::image2GrayScale(const QString& src, QString& err, bool upda
     }
 
     // Move back to original file
-    if (!Utils::MoveFile(tmp, src)) 
+    if (!Utils::moveOneFile(tmp, src)) 
     {
         err = i18n("Cannot update source image");
         return false;
@@ -157,7 +158,7 @@ bool ImageGrayScale::image2GrayScaleJPEG(const QString& src, const QString& dest
     input_file = fopen(QFile::encodeName(src), "rb");
     if (!input_file)
     {
-        kError( 51000 ) << "Image2GrayScale: Error in opening input file";
+        kError() << "Image2GrayScale: Error in opening input file";
         err = i18n("Error in opening input file");
         return false;
     }
@@ -166,7 +167,7 @@ bool ImageGrayScale::image2GrayScaleJPEG(const QString& src, const QString& dest
     if (!output_file)
     {
         fclose(input_file);
-        kError( 51000 ) << "Image2GrayScale: Error in opening output file";
+        kError() << "Image2GrayScale: Error in opening output file";
         err = i18n("Error in opening output file");
         return false;
     }
@@ -243,7 +244,7 @@ bool ImageGrayScale::image2GrayScaleImageMagick(const QString& src, const QStrin
     process << "-type" << "Grayscale";
     process << src + QString("[0]") << dest;
 
-    kDebug(51000) << "ImageMagick Command line: " << process.program();
+    kDebug() << "ImageMagick Command line: " << process.program();
 
     process.start();
 
