@@ -40,6 +40,7 @@
 
 // LibKExiv2 includes
 
+#include <libkexiv2/version.h>
 #include <libkexiv2/kexiv2.h>
 
 // Local includes
@@ -364,7 +365,11 @@ void EXIFAdjust::applyMetadata(QByteArray& exifData)
     else if (d->customRenderedCheck->isValid())
         exiv2Iface.removeExifTag("Exif.Photo.CustomRendered");
 
+#if KEXIV2_VERSION >= 0x010000
+    exifData = exiv2Iface.getExifEncoded();
+#else
     exifData = exiv2Iface.getExif();
+#endif
 }
 
 }  // namespace KIPIMetadataEditPlugin
