@@ -40,6 +40,7 @@
 
 // LibKExiv2 includes
 
+#include <libkexiv2/version.h>
 #include <libkexiv2/kexiv2.h>
 
 // Local includes
@@ -425,7 +426,11 @@ void EXIFLens::applyMetadata(QByteArray& exifData)
     else if (d->maxApertureCheck->isValid())
         exiv2Iface.removeExifTag("Exif.Photo.MaxApertureValue");
 
+#if KEXIV2_VERSION >= 0x010000
+    exifData = exiv2Iface.getExifEncoded();
+#else
     exifData = exiv2Iface.getExif();
+#endif
 }
 
 }  // namespace KIPIMetadataEditPlugin
