@@ -341,7 +341,13 @@ void IPTCEditDialog::slotItemChanged()
 {
     KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.load((*d->currItem).path());
+
+#if KEXIV2_VERSION >= 0x010000
+    d->exifData = exiv2Iface.getExifEncoded();
+#else
     d->exifData = exiv2Iface.getExif();
+#endif
+
     d->iptcData = exiv2Iface.getIptc();
     d->contentPage->readMetadata(d->iptcData);
     d->originPage->readMetadata(d->iptcData);
@@ -370,7 +376,7 @@ void IPTCEditDialog::slotItemChanged()
                .arg(d->urls.indexOf(*(d->currItem))+1)
                .arg(d->urls.count())
                .arg(i18n("Edit IPTC Metadata")) +
-               (d->isReadOnly ? QString(" - ") + i18n("(read only)") : QString::null));
+               (d->isReadOnly ? QString(" - ") + i18n("(read only)") : QString()));
     enableButton(User1, *(d->currItem) != d->urls.last());
     enableButton(User2, *(d->currItem) != d->urls.first());
     enableButton(Apply, false);
