@@ -42,6 +42,7 @@
 
 // LibKExiv2 includes
 
+#include <libkexiv2/version.h>
 #include <libkexiv2/kexiv2.h>
 
 // Local includes
@@ -292,7 +293,12 @@ void XMPContent::applyMetadata(QByteArray& exifData, QByteArray& xmpData)
     else if (d->copyrightEdit->isValid())
         exiv2Iface.removeXmpTag("Xmp.dc.rights");
 
+#if KEXIV2_VERSION >= 0x010000
+    exifData = exiv2Iface.getExifEncoded();
+#else
     exifData = exiv2Iface.getExif();
+#endif
+
     xmpData  = exiv2Iface.getXmp();
 }
 
