@@ -45,6 +45,7 @@
 
 // LibKExiv2 includes
 
+#include <libkexiv2/version.h>
 #include <libkexiv2/kexiv2.h>
 
 // LibKDcraw includes
@@ -766,7 +767,12 @@ void XMPOrigin::applyMetadata(QByteArray& exifData, QByteArray& xmpData)
         exiv2Iface.removeXmpTag("Xmp.photoshop.Country");
     }
 
+#if KEXIV2_VERSION >= 0x010000
+    exifData = exiv2Iface.getExifEncoded();
+#else
     exifData = exiv2Iface.getExif();
+#endif
+
     xmpData  = exiv2Iface.getXmp();
 }
 
