@@ -458,7 +458,7 @@ void PicasawebWindow::slotUploadImages()
 
         QStringList allTags;
 
-        QStringList tagsFromDialog = m_tagsLineEdit->text().split(" ", QString::SkipEmptyParts);
+        QStringList tagsFromDialog = m_tagsLineEdit->text().split(' ', QString::SkipEmptyParts);
         QStringList::Iterator itTags;
 
         // Tags from the interface
@@ -495,7 +495,7 @@ void PicasawebWindow::slotUploadImages()
         }
 
         temp.tags=allTags;
-        m_uploadQueue.append( Pair( (*it).path(), temp) );
+        m_uploadQueue.append( Pair( (*it).toLocalFile(), temp) );
     }
 
     m_uploadTotal = m_uploadQueue.count();
